# Messaging

Messaging commands are available only if Abaqus/CAE is run interactively using the GUI.

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Messaging.DataObject.DataObject
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Messaging.MonitorMgr.MonitorMgr
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
